@@ -1,14 +1,18 @@
-import numpy as np
+import math
 import time
+
+import numpy as np
 from scipy.ndimage import filters
 from scipy.ndimage import gaussian_filter
-import math
-from .. import utils
-from . import sparsedetect
+from matplotlib.colors import hsv_to_rgb
 
-def getSVDdata(ops):
-    mov, max_proj = sparsedetect.bin_movie(ops)
-    ops['max_proj'] = max_proj
+from .stats import fitMVGaus
+from .utils import temporal_high_pass_filter, standard_deviation_over_time
+
+def getSVDdata(mov: np.ndarray, ops):
+
+    mov = temporal_high_pass_filter(mov, width=int(ops['high_pass']))
+    ops['max_proj'] = mov.max(axis=0)
     nbins, Lyc, Lxc = np.shape(mov)
 
     sig = ops['diameter']/10. # PICK UP
@@ -16,28 +20,25 @@ def getSVDdata(ops):
         mov[j,:,:] = gaussian_filter(mov[j,:,:], sig)
 
     # compute noise variance across frames
-    sdmov = sparsedetect.get_sdmov(mov, ops)
+    sdmov = standard_deviation_over_time(mov, batch_size=ops['batch_size'])
     mov /= sdmov
     mov = np.reshape(mov, (-1,Lyc*Lxc))
-    if 1:
-        # compute covariance of binned frames
-        cov = mov @ mov.transpose() / mov.shape[1]
-        cov = cov.astype('float32')
+    # compute covariance of binned frames
+    cov = mov @ mov.transpose() / mov.shape[1]
+    cov = cov.astype('float32')
 
-        nsvd_for_roi = min(ops['nbinned'], int(cov.shape[0]/2))
-        u, s, v = np.linalg.svd(cov)
+    nsvd_for_roi = min(ops['nbinned'], int(cov.shape[0]/2))
+    u, s, v = np.linalg.svd(cov)
 
-        u = u[:, :nsvd_for_roi]
-        U = u.transpose() @ mov
-    else:
-        U = mov
-        u = []
+    u = u[:, :nsvd_for_roi]
+    U = u.transpose() @ mov
     U = np.reshape(U, (-1,Lyc,Lxc))
     U = np.transpose(U, (1, 2, 0)).copy()
     return ops, U, sdmov, u
 
-def getSVDproj(ops, u):
-    mov, _ = sparsedetect.bin_movie(ops)
+def getSVDproj(mov: np.ndarray, ops, u):
+
+    mov = temporal_high_pass_filter(mov, int(ops['high_pass']))
 
     nbins, Lyc, Lxc = np.shape(mov)
     if ('smooth_masks' in ops) and ops['smooth_masks']:
@@ -45,8 +46,7 @@ def getSVDproj(ops, u):
         for j in range(nbins):
             mov[j,:,:] = gaussian_filter(mov[j,:,:], sig)
     if 1:
-        #sdmov = np.ones((Lyc*Lxc,), 'float32')
-        sdmov = sparsedetect.get_sdmov(mov, ops)
+        sdmov = standard_deviation_over_time(mov, batch_size=ops['batch_size'])
         mov/=sdmov
         mov = np.reshape(mov, (-1,Lyc*Lxc))
 
@@ -199,8 +199,13 @@ def pairwiseDistance(y,x):
          + (np.expand_dims(x,axis=-1) - np.expand_dims(x,axis=0))**2)**0.5
     return dists
 
+
+def r_squared(yp, xp, ypix, xpix, diam_y, diam_x, estimator=np.median):
+    return np.sqrt(((yp - estimator(ypix)) / diam_y) ** 2 + (((xp - estimator(xpix)) / diam_x) ** 2))
+
+
 # this function needs to be updated with the new stat
-def get_stat(ops, stat, Ucell, codes):
+def get_stat(ops, stats, Ucell, codes, frac=0.5):
     '''computes statistics of cells found using sourcery
     inputs:
         Ly, Lx, d0, mPix (pixels,ncells), mLam (weights,ncells), codes (ncells,nsvd), Ucell (nsvd,Ly,Lx)
@@ -208,77 +213,59 @@ def get_stat(ops, stat, Ucell, codes):
         stat
         assigned to stat: ipix, ypix, xpix, med, npix, lam, footprint, compact, aspect_ratio, ellipse
     '''
-    d0 = ops['diameter']
-    Ly = ops['Lyc']
-    Lx = ops['Lxc']
-    rs,dy,dx = circleMask(d0)
+    d0, Ly, Lx = ops['diameter'], ops['Lyc'], ops['Lxc']
+    rs, dy, dx = circleMask(d0)
     rsort = np.sort(rs.flatten())
 
-    d0 = d0.astype('float32')
-    rs    = rs[rs<=1.]
-    frac = 0.5
-
     # Remove empty cells
-    stat = [elem for elem in stat if len(elem['ypix']) != 0]
-    ncells = len(stat)
-    
-    footprints = np.zeros((ncells,))
-    for k in range(0,ncells):
-        stat0 = stat[k]
-        ypix = stat0['ypix']
-        xpix = stat0['xpix']
-        lam = stat0['lam']
-        # compute footprint of ROI
-        y0 = np.median(ypix)
-        x0 = np.median(xpix)
-        yp, xp = extendROI(ypix,xpix,Ly,Lx, int(np.mean(d0)))
-        rs0 = (((yp-y0)/d0[0])**2 + ((xp-x0)/d0[1])**2)**.5
+    stats = [stat for stat in stats if len(stat['ypix']) != 0]
 
-        proj  = Ucell[yp, xp, :] @ np.expand_dims(codes[k,:], axis=1)
-        inds  = proj.flatten() > proj.max()*frac
-        footprints[k] = np.nanmean(rs0[inds])
+    footprints = np.zeros(len(stats))
+    for k, (stat, code) in enumerate(zip(stats, codes)):
+        ypix, xpix, lam = stat['ypix'], stat['xpix'], stat['lam']
+
+        # compute footprint of ROI
+        yp, xp = extendROI(ypix, xpix, Ly, Lx, int(np.mean(d0)))
 
         # compute compactness of ROI
-        r2 = ((ypix-y0)/d0[0])**2 + ((xpix-x0)/d0[1])**2
-        r2 = r2**.5
-        stat0['mrs']  = np.mean(r2)
-        stat0['mrs0'] = np.mean(rsort[:r2.size])
-        stat0['compact'] = stat0['mrs'] / (1e-10+stat0['mrs0'])
-        stat0['ypix'] += ops['yrange'][0]
-        stat0['xpix'] += ops['xrange'][0]
-        stat0['med']  = [np.median(stat0['ypix']), np.median(stat0['xpix'])]
-        stat0['npix'] = xpix.size
-        if 'radius' not in stat0:
-            radius = utils.fitMVGaus(ypix/d0[0], xpix/d0[1], lam, 2)[2]
-            stat0['radius'] = radius[0] * d0.mean()
-            stat0['aspect_ratio'] = 2 * radius[0]/(.01 + radius[0] + radius[1])
+        rs = r_squared(yp=yp, xp=xp, ypix=ypix, xpix=xpix, diam_y=d0[0], diam_x=d0[1])
+        stat['mrs'] = np.mean(rs)
+        stat['mrs0'] = np.mean(rsort[:ypix.size])
+        stat['compact'] = stat['mrs'] / (1e-10 + stat['mrs0'])
+        stat['ypix'] += ops['yrange'][0]
+        stat['xpix'] += ops['xrange'][0]
+        stat['med'] = [np.median(stat['ypix']), np.median(stat['xpix'])]
+        stat['npix'] = xpix.size
+        if 'radius' not in stat:
+            ry, rx = fitMVGaus(ypix, xpix, lam, dy=d0[0], dx=d0[1], thres=2).radii
+            stat['radius'] = ry * d0.mean()
+            stat['aspect_ratio'] = 2 * ry/(.01 + ry + rx)
+
+        proj = (Ucell[yp, xp, :] @ np.expand_dims(code, axis=1)).flatten()
+        footprints[k] = np.nanmean(rs[proj > proj.max() * frac])
 
     mfoot = np.nanmedian(footprints)
-    for n in range(len(stat)):
-        stat[n]['footprint'] = footprints[n] / mfoot
-        if np.isnan(stat[n]['footprint']):
-            stat[n]['footprint'] = 0
-    npix = np.array([stat[n]['npix'] for n in range(len(stat))]).astype('float32')
+    for stat, footprint in zip(stats, footprints):
+        stat['footprint'] = footprint / mfoot if not np.isnan(footprint) else 0
+
+    npix = np.array([stat['npix'] for stat in stats], dtype='float32')
     npix /= np.mean(npix[:100])
-    #mmrs = np.nanmedian(mrs[:100])
-    for n in range(len(stat)):
-        #stat[n]['mrs'] = stat[n]['mrs'] / (1e-10+mmrs)
-        stat[n]['npix_norm'] = npix[n]
-    return stat
+    for stat, npix0 in zip(stats, npix):
+        stat['npix_norm'] = npix0
+
+    return stats
+
 
 def getVmap(Ucell, sig):
-    us = gaussian_filter(Ucell, [sig[0], sig[1], 0.],  mode='wrap')
+    us = gaussian_filter(Ucell, [sig[0], sig[1], 0.], mode='wrap')
     # compute log variance at each location
-    V  = (us**2).mean(axis=-1)
-    um = (Ucell**2).mean(axis=-1)
-    um = gaussian_filter(um, sig,  mode='wrap')
-    V  = V / um
-    V  = V.astype('float64')
-    return V, us
+    log_variances = (us**2).mean(axis=-1) / gaussian_filter((Ucell**2).mean(axis=-1), sig, mode='wrap')
+    return log_variances.astype('float64'), us
+
 
 def sub2ind(array_shape, rows, cols):
-    inds = rows * array_shape[1] + cols
-    return inds
+    return rows * array_shape[1] + cols
+
 
 def minDistance(inputs):
     y1, x1, y2, x2 = inputs
@@ -349,7 +336,7 @@ def iter_extend(ypix, xpix, Ucell, code, refine=-1, change_codes=False):
         iter += 1
     return ypix, xpix, lam, ix, code
 
-def sourcery(ops):
+def sourcery(mov: np.ndarray, ops):
     change_codes = True
     i0 = time.time()
     if isinstance(ops['diameter'], int):
@@ -357,7 +344,7 @@ def sourcery(ops):
     ops['diameter'] = np.array(ops['diameter'])
     ops['spatscale_pix'] = ops['diameter'][1]
     ops['aspect'] = ops['diameter'][0] / ops['diameter'][1]
-    ops, U,sdmov, u   = getSVDdata(ops) # get SVD components
+    ops, U,sdmov, u   = getSVDdata(mov=mov, ops=ops) # get SVD components
     S, StU , StS = getStU(ops, U)
     Lyc, Lxc,nsvd = U.shape
     ops['Lyc'] = Lyc
@@ -486,7 +473,7 @@ def sourcery(ops):
             Ucell = Ucell + (S.reshape((-1,nbasis))@neu).reshape(U.shape)
         if refine<0 and (newcells<Nfirst/10 or it==ops['max_iterations']):
             refine = 3
-            U, sdmov = getSVDproj(ops, u)
+            U, sdmov = getSVDproj(mov, ops, u)
             Ucell = U
         if refine>=0:
             StU = S.reshape((Lyc*Lxc,-1)).transpose() @ Ucell.reshape((Lyc*Lxc,-1))
