@@ -1,15 +1,16 @@
-from PyQt5 import QtGui, QtCore
+import sys
+import time
+
 import numpy as np
 import pyqtgraph as pg
-from scipy.ndimage import gaussian_filter1d
-from scipy.sparse.linalg import eigsh
-from scipy.stats import zscore
-from matplotlib.colors import hsv_to_rgb
+from PyQt5 import QtGui, QtCore
 from matplotlib import cm
-import time
-import sys,os
 from rastermap.mapping import Rastermap
-from . import rungui,masks
+from scipy.ndimage import gaussian_filter1d
+from scipy.stats import zscore
+
+from . import masks
+
 
 # custom vertical label
 class VerticalLabel(QtGui.QWidget):
