@@ -1,25 +1,21 @@
 import os
-
+from natsort import natsorted
 import numpy as np
 import scipy
 
 
-def save_combined(ops1):
-    """ Combines all the entries in ops1 into a single result file.
-
-    Multi-plane recordings are arranged to best tile a square.
-    Multi-roi recordings are arranged by their dx,dy physical localization.
-    """
+def compute_dydx(ops1):
     ops = ops1[0].copy()
-        
+    dx = np.zeros(len(ops1), np.int64)
+    dy = np.zeros(len(ops1), np.int64)
     if ('dx' not in ops) or ('dy' not in ops):
         Lx = ops['Lx']
         Ly = ops['Ly']
         nX = np.ceil(np.sqrt(ops['Ly'] * ops['Lx'] * len(ops1))/ops['Lx'])
         nX = int(nX)
         for j in range(len(ops1)):
-            ops1[j]['dx'] = (j%nX) * Lx
-            ops1[j]['dy'] = int(j/nX) * Ly
+            dx[j] = (j%nX) * Lx
+            dy[j] = int(j/nX) * Ly
     else:
         dx = np.array([o['dx'] for o in ops1])
         dy = np.array([o['dy'] for o in ops1])
@@ -36,18 +32,33 @@ def save_combined(ops1):
             nY = int(np.ceil(len(ops1)/nX))
             for j in range(nplanes):
                 for k in range(nrois):
-                    ops1[j*nrois + k]['dx'] += (j%nX) * xmax
-                    ops1[j*nrois + k]['dy'] += int(j/nX) * ymax    
+                    dx[j*nrois + k] += (j%nX) * xmax
+                    dy[j*nrois + k] += int(j/nX) * ymax 
+    return dy, dx
 
-    LY = int(np.amax(np.array([ops['Ly']+ops['dy'] for ops in ops1])))
-    LX = int(np.amax(np.array([ops['Lx']+ops['dx'] for ops in ops1])))
+def combined(save_folder, save=True):
+    """ Combines all the folders in save_folder into a single result file.
+
+    can turn off saving (for gui loading)
+
+    Multi-plane recordings are arranged to best tile a square.
+    Multi-roi recordings are arranged by their dx,dy physical localization.
+    Multi-plane / multi-roi recordings are tiled after using dx,dy.
+    """
+    plane_folders = natsorted([ f.path for f in os.scandir(save_folder) if f.is_dir() and f.name[:5]=='plane'])
+    ops1 = [np.load(os.path.join(f, 'ops.npy'), allow_pickle=True).item() for f in plane_folders]
+    dy, dx = compute_dydx(ops1)
+    Ly = np.array([ops['Ly'] for ops in ops1])
+    Lx = np.array([ops['Lx'] for ops in ops1])
+    LY = int(np.amax(dy + Ly))
+    LX = int(np.amax(dx + Lx))
     meanImg = np.zeros((LY, LX))
     meanImgE = np.zeros((LY, LX))
-    if ops['nchannels']>1:
+    if ops1[0]['nchannels']>1:
         meanImg_chan2 = np.zeros((LY, LX))
-    if 'meanImg_chan2_corrected' in ops:
+    if 'meanImg_chan2_corrected' in ops1[0]:
         meanImg_chan2_corrected = np.zeros((LY, LX))
-    if 'max_proj' in ops:
+    if 'max_proj' in ops1[0]:
         max_proj = np.zeros((LY, LX))
 
     Vcorr = np.zeros((LY, LX))
@@ -55,8 +66,8 @@ def save_combined(ops1):
     for k,ops in enumerate(ops1):
         fpath = ops['save_path']
         stat0 = np.load(os.path.join(fpath,'stat.npy'), allow_pickle=True)
-        xrange = np.arange(ops['dx'],ops['dx']+ops['Lx'])
-        yrange = np.arange(ops['dy'],ops['dy']+ops['Ly'])
+        xrange = np.arange(dx[k], dx[k] + Lx[k])
+        yrange = np.arange(dy[k], dy[k] + Ly[k])
         meanImg[np.ix_(yrange, xrange)] = ops['meanImg']
         meanImgE[np.ix_(yrange, xrange)] = ops['meanImgE']
         if ops['nchannels']>1:
@@ -65,16 +76,16 @@ def save_combined(ops1):
         if 'meanImg_chan2_corrected' in ops:
             meanImg_chan2_corrected[np.ix_(yrange, xrange)] = ops['meanImg_chan2_corrected']
 
-        xrange = np.arange(ops['dx']+ops['xrange'][0],ops['dx']+ops['xrange'][-1])
-        yrange = np.arange(ops['dy']+ops['yrange'][0],ops['dy']+ops['yrange'][-1])
+        xrange = np.arange(dx[k]+ops['xrange'][0],dx[k]+ops['xrange'][-1])
+        yrange = np.arange(dy[k]+ops['yrange'][0],dy[k]+ops['yrange'][-1])
         Vcorr[np.ix_(yrange, xrange)] = ops['Vcorr']
         if 'max_proj' in ops:
             max_proj[np.ix_(yrange, xrange)] = ops['max_proj']
         for j in range(len(stat0)):
-            stat0[j]['xpix'] += ops['dx']
-            stat0[j]['ypix'] += ops['dy']
-            stat0[j]['med'][0] += ops['dy']
-            stat0[j]['med'][1] += ops['dx']
+            stat0[j]['xpix'] += dx[k]
+            stat0[j]['ypix'] += dy[k]
+            stat0[j]['med'][0] += dy[k]
+            stat0[j]['med'][1] += dx[k]
             stat0[j]['iplane'] = k
         F0    = np.load(os.path.join(fpath,'F.npy'))
         Fneu0 = np.load(os.path.join(fpath,'Fneu.npy'))
@@ -95,7 +106,7 @@ def save_combined(ops1):
             spks0   = np.concatenate((spks0, fcat), axis=1)
             Fneu0   = np.concatenate((Fneu0, fcat), axis=1)
         if k==0:
-            F, Fneu, spks,stat,iscell,redcell = F0, Fneu0, spks0,stat0, iscell0, redcell0
+            F, Fneu, spks, stat, iscell, redcell = F0, Fneu0, spks0, stat0, iscell0, redcell0
         else:
             F    = np.concatenate((F, F0))
             Fneu = np.concatenate((Fneu, Fneu0))
@@ -124,24 +135,31 @@ def save_combined(ops1):
     if not os.path.isdir(fpath):
         os.makedirs(fpath)
     ops['save_path'] = fpath
-    np.save(os.path.join(fpath, 'F.npy'), F)
-    np.save(os.path.join(fpath, 'Fneu.npy'), Fneu)
-    np.save(os.path.join(fpath, 'spks.npy'), spks)
-    np.save(os.path.join(fpath, 'ops.npy'), ops)
-    np.save(os.path.join(fpath, 'stat.npy'), stat)
+
+    # need to save iscell regardless (required for GUI function)
     np.save(os.path.join(fpath, 'iscell.npy'), iscell)
     if hasred:
         np.save(os.path.join(fpath, 'redcell.npy'), redcell)
+    else:
+        redcell = np.zeros_like(iscell)
 
-    # save as matlab file
-    if ('save_mat' in ops) and ops['save_mat']:
-        matpath = os.path.join(ops['save_path'],'Fall.mat')
-        scipy.io.savemat(matpath, {'stat': stat,
-                                    'ops': ops,
-                                    'F': F,
-                                    'Fneu': Fneu,
-                                    'spks': spks,
-                                    'iscell': iscell,
-                                    'redcell': redcell})
-    return ops
+    if save:
+        np.save(os.path.join(fpath, 'F.npy'), F)
+        np.save(os.path.join(fpath, 'Fneu.npy'), Fneu)
+        np.save(os.path.join(fpath, 'spks.npy'), spks)
+        np.save(os.path.join(fpath, 'ops.npy'), ops)
+        np.save(os.path.join(fpath, 'stat.npy'), stat)
+        
+        # save as matlab file
+        if ('save_mat' in ops) and ops['save_mat']:
+            matpath = os.path.join(ops['save_path'],'Fall.mat')
+            scipy.io.savemat(matpath, {'stat': stat,
+                                        'ops': ops,
+                                        'F': F,
+                                        'Fneu': Fneu,
+                                        'spks': spks,
+                                        'iscell': iscell,
+                                        'redcell': redcell})
+
+    return stat, ops, F, Fneu, spks, iscell[:,0], iscell[:,1], redcell[:,0], redcell[:,1], hasred
 
