@@ -2,7 +2,7 @@ import os
 
 import numpy as np
 
-from . import utils
+from .utils import init_ops, find_files_open_binaries
 
 
 def sbx_get_info(sbxfile):
@@ -12,7 +12,7 @@ def sbx_get_info(sbxfile):
     '''
     matfile = os.path.splitext(sbxfile)[0] + '.mat'
     if not os.path.exists(matfile):
-        raise('Metadata not found: {0}'.format(matfile))
+        raise FileNotFoundError('Metadata not found: {0}'.format(matfile))
     from scipy.io import loadmat
     info = loadmat(matfile,squeeze_me=True,struct_as_record=False)
     return info['info']
@@ -90,17 +90,17 @@ def sbx_to_binary(ops,ndeadcols = -1):
 
     Returns
     -------
-        ops1 : list of dictionaries
-            'Ly', 'Lx', ops1[j]['reg_file'] or ops1[j]['raw_file'] is created binary
+        ops : dictionary of first plane
+            'Ly', 'Lx', ops['reg_file'] or ops['raw_file'] is created binary
 
     """
 
-    ops1 = utils.init_ops(ops)
+    ops1 = init_ops(ops)
     # the following should be taken from the metadata and not needed but the files are initialized before...
     nplanes = ops1[0]['nplanes']
     nchannels = ops1[0]['nchannels']
     # open all binary files for writing
-    ops1, sbxlist, reg_file, reg_file_chan2 = utils.find_files_open_binaries(ops1)
+    ops1, sbxlist, reg_file, reg_file_chan2 = find_files_open_binaries(ops1)
     iall = 0
     for j in range(ops1[0]['nplanes']):
         ops1[j]['nframes_per_folder'] = np.zeros(len(sbxlist), np.int32)
@@ -180,4 +180,4 @@ def sbx_to_binary(ops,ndeadcols = -1):
         reg_file[j].close()
         if nchannels>1:
             reg_file_chan2[j].close()
-    return ops1
+    return ops1[0]
