@@ -1,3 +1,3 @@
+from .register import register_binary, sampled_mean
 from .metrics import get_pc_metrics
-from .register import register_binary, pick_initial_reference
 from .zalign import compute_zpos
